@@ -24,6 +24,15 @@ circle_fields = ["@id", "name", "subtitle", "description", "creationDate", "stat
 if 'djangoldp_community' in settings.DJANGOLDP_PACKAGES:
     circle_fields += ['community']
 
+if 'djangoldp_polls' in settings.DJANGOLDP_PACKAGES:
+    circle_fields += ['polls']
+
+if 'djangoldp_resource' in settings.DJANGOLDP_PACKAGES:
+    circle_fields += ['resources']
+
+if 'djangoldp_event' in settings.DJANGOLDP_PACKAGES:
+    circle_fields += ['events']
+
 
 class Circle(Model):
     name = models.CharField(max_length=255, blank=True, null=True, default='')
